SystemOrganization addCategory: #'DAO-Satellite'!

TestCase subclass: #CommandDecoderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

TestCase subclass: #CommandEncoderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandEncoderTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 18:09'!
testEncodeCommandWithoutParameters
	"comment stating purpose of message"

	| encoder string sequenceNumber byteString |
	
	string := 'MAC'.
	sequenceNumber := 1.
	string := string , sequenceNumber.

	byteString := encoder encode: string.! !

TestCase subclass: #CommandInterpreterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandInterpreterTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:04'!
commandInterpreter
	| satellite commandInterpreter |
	
	satellite := SatelliteTest satelliteWithThermalAndMemorySubsystems.
	commandInterpreter := satellite commandInterpreter.
	
	^ commandInterpreter.! !

!CommandInterpreterTest methodsFor: 'command' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:34'!
testWhenParsingNameCommandForSubsystemIdCommandIsReturned
	| satellite commandInterpreter command |
	
	"setup"
	satellite := SatelliteTest satelliteWithThermalAndMemorySubsystems.
	commandInterpreter := satellite commandInterpreter.
	
	"exercise"
	"subsystem 3 is THERMAL"
	command := commandInterpreter parseFromName: 'name' andSubsystemId: 3.
	
	"verify"
	self assert: (command receiver) equals: (SatelliteTest thermalSubsystem).
	self assert: (command class) equals: GetNameCommand.! !

!CommandInterpreterTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:38'!
testWhenReceivesSubsystemIdTheCorrespondingSubsytemIsResolved

	| commandInterpreter subsystem |
	
	commandInterpreter := self commandInterpreter.
	
	subsystem := commandInterpreter resolveSubsystem: 3.
	
	self assert: subsystem equals: (SatelliteTest thermalSubsystem).
! !

TestCase subclass: #CommandSequenceNumberTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandSequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 19:12'!
test1AsByteArray
	| sequenceNumber |

	sequenceNumber := CommandSequenceNumber new.

	self assert: sequenceNumber asByteArray equals: #[0 0 1].! !

!CommandSequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 19:10'!
testLastSequenceNumberAsByteArray
	| sequenceNumber lastNumber |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFF0' base: 16.

	sequenceNumber := CommandSequenceNumber newWithStart: lastNumber.

	self assert: sequenceNumber asByteArray equals: #[255 255 240].! !

!CommandSequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 15:22'!
testNewSequenceNumberStartsIn1
	| sequenceNumber |
	
	sequenceNumber := CommandSequenceNumber new.
	
	self assert: sequenceNumber number equals: 1! !

!CommandSequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 14:56'!
testNextOfFFFFF0Is1
	| lastNumber sequenceNumber one |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFF0' base: 16.
	sequenceNumber := CommandSequenceNumber newWithStart: lastNumber.
	one := sequenceNumber next.
	
	self assert: one equals: 1! !

TestCase subclass: #CommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandTest methodsFor: 'command' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:13'!
testSendingNameCommandToThermalSubsystem
	| thermalSubsystem command response echoResponse |
	
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	command := GetNameCommand newWithReceiver: thermalSubsystem.

	echoResponse := MessageCommandResponse newWithMessage: 'THERMAL'.

	"exercise"
	response := command execute.
	
	"verify"
	self assert: response equals: echoResponse.! !

!CommandTest methodsFor: 'command' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:13'!
testSendingSetMatrixKeyCommandToThermalSubsystem
	| thermalSubsystem command response voidResponse |
	
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	command := SetMatrixKeyCommand newWithReceiver: thermalSubsystem.
	voidResponse := VoidCommandResponse new.

	"exercise"
	response := command executeWithParameter: 10.
	
	"verify"
	self assert: response equals: voidResponse.
	self assert: (thermalSubsystem getValueOfAttribute: 'matrix_key') equals: 10.! !

TestCase subclass: #SatelliteSubsystemTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:23'!
testWhenCreatingASubsystemItCanAnswerBasicCommands

	| subsystem |

	"setup"
	subsystem := SatelliteTest memorySubsystem.

	"verify"	
	self assert: (subsystem understands: GetNameCommand).
	self assert: (subsystem understands: GetTelemetryCommand).
	self assert: (subsystem understands: GetShortTelemetryCommand).
! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:24'!
testWhenCreatingASubsystemItDoesntUnderstandUnknwonCommand

	| subsystem notACommand |

	"setup"
	subsystem := SatelliteTest memorySubsystem.
	notACommand := Object new.

	"verify"	
	self deny: (subsystem understands: notACommand).
! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 19:15'!
testWhenCreatingASubsystemTheIdAndNameIsSet

	| subsystem |

	"setup"
	subsystem := MemorySatelliteSubsystem newWithId: 1 andName: 'MEMORY'.

	"verify"	
	self assert: subsystem id equals: 1.
	self assert: subsystem name equals: 'MEMORY'.
! !

TestCase subclass: #SatelliteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:53'!
memorySubsystem
	| memorySubsystem |

	memorySubsystem := MemorySatelliteSubsystem newWithId: 1 andName: 'MEMORY'.
	memorySubsystem setAttribute: 'free' withValue: 100.
	
	^ memorySubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:54'!
satelliteWithThermalAndMemorySubsystems
	| subsystems |

	subsystems := Set new.	
	subsystems add: self memorySubsystem.
	subsystems add: self thermalSubsystem.

	^ Satellite newWithSubsystems: subsystems.
! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:53'!
thermalSubsystem
	| thermalSubsystem |

	thermalSubsystem := ThermalSatelliteSubsystem newWithId: 3 andName: 'THERMAL'.
	thermalSubsystem setAttribute: 'battery_temp' withValue: 10.
	thermalSubsystem setAttribute: 'radio_temp' withValue: 20.
	
	^ thermalSubsystem! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:27'!
testGivenASatelliteWhenEmittingAShortBeaconItReturnsAShortBeacon

	| satellite subsystems thermalSubsystem expectedBeacon beacon |

	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	thermalSubsystem setAttribute: 'battery_temp' withValue: '10'.
	thermalSubsystem setAttribute: 'radio_temp' withValue: '20'.
	subsystems := Set new.
	subsystems add: thermalSubsystem.
	satellite := Satellite newWithSubsystems: subsystems.
	expectedBeacon := '{"short_telemetry":[{"subsystem_id":"3","battery_temp":"10"}]}'.

	"exercise"	
	beacon := satellite emitShortBeacon.

	"verify"	
	self assert: beacon equals: expectedBeacon.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 12:46'!
testGivenASatelliteWithThermalSubsystemOnlyWhenEmittingABeaconTheBeaconContainsOnlyThermalTelemetry

	| satellite subsystems thermalSubsystem expectedBeacon beacon |

	"setup"
	thermalSubsystem := ThermalSatelliteSubsystem newWithId: 3 andName: 'THERMAL'.
	thermalSubsystem setAttribute: 'battery_temp' withValue: '10'.
	thermalSubsystem setAttribute: 'radio_temp' withValue: '20'.
	subsystems := Set new.
	subsystems add: thermalSubsystem.
	satellite := Satellite newWithSubsystems: subsystems.
	expectedBeacon := '{"telemetry":[{"subsystem_id":"3","battery_temp":"10","radio_temp":"20"}]}'.

	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon equals: expectedBeacon.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:15'!
testGivenASatelliteWithTwoSubsystemsWhenEmittingABeaconTheBeaconContainsTwoTelemetryData

	| satellite expectedBeacon beacon |

	"setup"
	satellite := SatelliteTest satelliteWithThermalAndMemorySubsystems.

	expectedBeacon := '{"telemetry":[{"subsystem_id":"1","free":"100"},{"subsystem_id":"3","battery_temp":"10","radio_temp":"20"}]}'.

	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon equals: expectedBeacon.
! !

Object subclass: #CommandInterpreter
	instanceVariableNames: 'subsystems commandClasses'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!CommandInterpreter class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:14'!
newWithSubsystems: theSubsystems
	^ self new initializeWithSubystems: theSubsystems.! !

!CommandInterpreter methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:14'!
initializeWithSubystems: theSubsystems
	subsystems := Dictionary new.
	theSubsystems do: [ :subsystem | subsystems at: (subsystem id) put: subsystem].
	
	commandClasses := Dictionary new.
	commandClasses at: 'name' put: GetNameCommand.
	commandClasses at: 'telemetry' put: GetTelemetryCommand.
	commandClasses at: 'short_telemetry' put: GetShortTelemetryCommand.
	commandClasses at: 'setMatrixKey' put: SetMatrixKeyCommand.! !

!CommandInterpreter methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:02'!
parseFromName: aCommandName andSubsystemId: aSubsystemId 

	| subsystem commandClass command |
	
	subsystem := self resolveSubsystem: aSubsystemId.
	
	commandClass := commandClasses at: aCommandName.
	
	command := commandClass newWithReceiver: subsystem.
	
	^ command.! !

!CommandInterpreter methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:10'!
resolveSubsystem: aKey 
	^ subsystems at: aKey.! !

Object subclass: #CommandResponse
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

CommandResponse subclass: #MessageCommandResponse
	instanceVariableNames: 'message'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!MessageCommandResponse class methodsFor: 'class initialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 21:06'!
newWithMessage: aMessage 
	self new initializeWithMessage: aMessage.! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 21:01'!
= anObject
	^ message = anObject message
! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 21:02'!
initialize
	message = ''
! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 21:06'!
initializeWithMessage: aMessage 
	message := aMessage.! !

!MessageCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 21:02'!
message
	^ message
! !

CommandResponse subclass: #VoidCommandResponse
	instanceVariableNames: 'code'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!VoidCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 20:58'!
= anotherResponse
	"TODO reemplazar con una sola instancia global de VoidCommandResponse"
	^ code = anotherResponse code ! !

!VoidCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 20:58'!
code
	^ code! !

!VoidCommandResponse methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 20:56'!
initialize
	code = -1
! !

Object subclass: #CommandSequenceNumber
	instanceVariableNames: 'number lastNumber'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

CommandSequenceNumber class
	instanceVariableNames: 'number'!

CommandSequenceNumber class
	instanceVariableNames: 'number'!

!CommandSequenceNumber class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 14:57'!
newWithStart: aNumber
	^ self new initializeWithStart: aNumber! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 19:08'!
asByteArray
	| resultSize resultBytes sequenceNumber start |

	resultSize := 3.

	resultBytes := ByteArray new: resultSize.
	
	sequenceNumber := number asByteArray.

	start := (resultSize - (sequenceNumber size) + 1).

	^ resultBytes replaceFrom: start to: resultSize with: sequenceNumber. 
! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 14:50'!
initialize
	number := 1.
	lastNumber := LargePositiveInteger readFrom: 'FFFFF0' base: 16.
! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 14:58'!
initializeWithStart: aNumber
	self initialize.
	number := aNumber.! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 14:53'!
next
	number := number + 1.
	number > lastNumber ifTrue: [ self reset. ].
	^ number.
! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 15:00'!
number
	^ number! !

!CommandSequenceNumber methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/15/2013 14:52'!
reset
	number := 1.! !

Object subclass: #Satellite
	instanceVariableNames: 'subsystems commandInterpreter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!Satellite class methodsFor: 'instance creation' stamp: 'EmilianoMenendez 9/7/2013 16:27'!
newWithSubsystems: theSubsystems 
	^ self new initalizeWithSubsystems: theSubsystems! !

!Satellite methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:54'!
commandInterpreter
	^ commandInterpreter! !

!Satellite methodsFor: 'signaling' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 19:48'!
emitBeacon
	| result outputStream telemetryDataOrderedBySubsystemId |
	
	outputStream := WriteStream on: String new.
	
	outputStream nextPutAll: '{"telemetry":['.
	
	telemetryDataOrderedBySubsystemId := OrderedIdentityDictionary new.
	
	subsystems do: [ :subsystem | telemetryDataOrderedBySubsystemId at: (subsystem id) put: subsystem telemetry].
	
	telemetryDataOrderedBySubsystemId do: [ :telemetry | outputStream nextPutAll: telemetry. outputStream nextPutAll: ',' ].
	
	result := outputStream contents.
	
	result := result truncateTo: ((result size) - 1).
	
	result := result , ']}'.
	
	^ result.
! !

!Satellite methodsFor: 'signaling' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 21:06'!
emitShortBeacon
	| result outputStream telemetryDataOrderedBySubsystemId |
	
	outputStream := WriteStream on: String new.
	
	outputStream nextPutAll: '{"short_telemetry":['.
	
	telemetryDataOrderedBySubsystemId := OrderedIdentityDictionary new.
	
	subsystems do: [ :subsystem | telemetryDataOrderedBySubsystemId at: (subsystem id) put: subsystem shortTelemetry].
	
	telemetryDataOrderedBySubsystemId do: [ :telemetry | outputStream nextPutAll: telemetry. outputStream nextPutAll: ',' ].
	
	result := outputStream contents.
	
	result := result truncateTo: ((result size) - 1).
	
	result := result , ']}'.
	
	^ result.
! !

!Satellite methodsFor: 'initialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 14:32'!
initalizeWithSubsystems: theSubsystems

	subsystems := theSubsystems.
	
	commandInterpreter := CommandInterpreter newWithSubsystems: subsystems.


! !

!Satellite methodsFor: 'accessing' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 19:59'!
subsystems
	
	^ subsystems
! !

Object subclass: #SatelliteCommand
	instanceVariableNames: 'receiver'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

SatelliteCommand subclass: #GetNameCommand
	instanceVariableNames: 'receiver'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!GetNameCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:12'!
execute
	^ MessageCommandResponse newWithMessage: (receiver name)! !

SatelliteCommand subclass: #GetShortTelemetryCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

SatelliteCommand subclass: #GetTelemetryCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!SatelliteCommand class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:10'!
newWithReceiver: aReceiver
	^ self new initializeWithReceiver: aReceiver! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:11'!
execute
	^ self subclassResponsibility.! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:12'!
executeWithParameter: parameter
	^ self subclassResponsibility.! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:10'!
initializeWithReceiver: aReceiver

	receiver := aReceiver
	! !

!SatelliteCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:13'!
receiver
	^ receiver! !

SatelliteCommand subclass: #SetMatrixKeyCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!SetMatrixKeyCommand methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 15:12'!
executeWithParameter: parameter
	receiver setMatrixKey: parameter.
	
	^ VoidCommandResponse new.
	! !

Object subclass: #SatelliteSubsystem
	instanceVariableNames: 'id data telemetryKeys shortTelemetryKeys name commands'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

SatelliteSubsystem subclass: #MemorySatelliteSubsystem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!MemorySatelliteSubsystem class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 16:00'!
newWithId: theId andName: theName
	| subsystem telemetryKeys shortTelemetryKeys |
	
	telemetryKeys := Set new.
	telemetryKeys add: 'free'.
	
	shortTelemetryKeys := Set new.
	shortTelemetryKeys add: 'free'.
	
	subsystem := self new initializeWithId: theId andName: theName andTelemetryKeys: telemetryKeys andShortTelemetryKeys: shortTelemetryKeys.
	
	^ subsystem.! !

!SatelliteSubsystem class methodsFor: 'accessing' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:26'!
basicCommands
	| commands |
	
	commands := Set new.

	commands add: GetNameCommand.
	commands add: GetTelemetryCommand.
	commands add: GetShortTelemetryCommand.

	^ commands! !

!SatelliteSubsystem class methodsFor: 'creation' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 18:58'!
newWithId: theId andName: theName
	^ self new initializeWithId: theId andName: theName andTelemetryKeys: Set new andShortTelemetryKeys: Set new! !

!SatelliteSubsystem methodsFor: 'command' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:35'!
= anObject
	^ id = anObject id! !

!SatelliteSubsystem methodsFor: 'accessing' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 18:27'!
commands
	^ commands! !

!SatelliteSubsystem methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:03'!
getValueOfAttribute: aKey
	^ (data at: aKey)! !

!SatelliteSubsystem methodsFor: 'accessing' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 16:10'!
id
	^ id! !

!SatelliteSubsystem methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 20:26'!
initializeWithId: theId andName: theName andTelemetryKeys: theTelemetryKeys andShortTelemetryKeys: theShortTelemetryKeys
	id := theId.
	name := theName.
	commands := SatelliteSubsystem basicCommands.
	telemetryKeys := theTelemetryKeys.
	shortTelemetryKeys := theShortTelemetryKeys.
	data := Dictionary new.! !

!SatelliteSubsystem methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/10/2013 19:37'!
initializeWithId: theId andName: theName andTelemetryKeys: theTelemetryKeys andShortTelemetryKeys: theShortTelemetryKeys andCommands: theCommands
	id := theId.
	name := theName.
	commands := SatelliteSubsystem basicCommands.
	commands add: theCommands.
	telemetryKeys := theTelemetryKeys.
	shortTelemetryKeys := theShortTelemetryKeys.
	data := Dictionary new.! !

!SatelliteSubsystem methodsFor: 'command' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/9/2013 16:11'!
name
	^ name! !

!SatelliteSubsystem methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 12:46'!
setAttribute: aKey withValue: aValue 
	data at: aKey put: aValue! !

!SatelliteSubsystem methodsFor: 'command' stamp: 'EmilianoMenendez 9/9/2013 10:26'!
shortTelemetry
	| result temp |
	
	temp := WriteStream on: String new.
	
	temp nextPutAll: '{'.
	
	"add subsytem_id"
	temp nextPutAll: '"subsystem_id":"'.
	temp nextPutAll: id asString.
	temp nextPutAll: '",'.
	
	"build key:value,key:value,,, string "
	data associationsDo: [ :entry | (shortTelemetryKeys includes: (entry key)) ifTrue: [temp nextPutAll: '"'. temp nextPutAll: (entry key asString) . temp nextPutAll: '":"'. temp nextPutAll: (entry value asString). temp nextPutAll: '",'.]].
	
	"send stream to string"
	result := temp contents.
	
	"remove last ,"
	result := result truncateTo: ((result size) - 1).
	
	result := result , '}'.
	
	^ result
! !

!SatelliteSubsystem methodsFor: 'command' stamp: 'EmilianoMenendez 9/8/2013 20:40'!
telemetry
	| result temp |
	
	temp := WriteStream on: String new.
	
	temp nextPutAll: '{'.
	
	"add subsytem_id"
	temp nextPutAll: '"subsystem_id":"'.
	temp nextPutAll: id asString.
	temp nextPutAll: '",'.
	
	"build key:value,key:value,,, string "
	data associationsDo: [ :entry | temp nextPutAll: '"'. temp nextPutAll: (entry key asString) . temp nextPutAll: '":"'. temp nextPutAll: (entry value asString). temp nextPutAll: '",'.].
	
	"send stream to string"
	result := temp contents.
	
	"remove last ,"
	result := result truncateTo: ((result size) - 1).
	
	result := result , '}'.
	
	^ result
! !

!SatelliteSubsystem methodsFor: 'accessing' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:22'!
understands: aCommandClass
	^ (commands includes: aCommandClass).! !

SatelliteSubsystem subclass: #ThermalSatelliteSubsystem
	instanceVariableNames: 'matrixKey'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-Satellite'!

!ThermalSatelliteSubsystem class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:13'!
newWithId: theId andName: theName
	| subsystem telemetryKeys shortTelemetryKeys matrixKeyCommand matrixKeyCommandEntry |
	
	telemetryKeys := Set new.
	telemetryKeys add: 'battery_temp'.
	telemetryKeys add: 'radio_temp'.
	
	shortTelemetryKeys := Set new.
	shortTelemetryKeys add: 'battery_temp'.
	
	matrixKeyCommand := SetMatrixKeyCommand new.
	matrixKeyCommandEntry := Association key: 'setMatrixKey' value: matrixKeyCommand.
	
	subsystem := self new initializeWithId: theId andName: theName andTelemetryKeys: telemetryKeys andShortTelemetryKeys: shortTelemetryKeys andCommands: matrixKeyCommandEntry.
	
	^ subsystem.! !

!ThermalSatelliteSubsystem methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/14/2013 16:07'!
setMatrixKey: theValue
	data at: 'matrix_key' put: theValue! !
